@@ -11,6 +11,7 @@
 #include <QDBusPendingReply>
 #include <QDesktopServices>
 
+#include <KIO/OpenUrlJob>
 #include <KLocalizedString>
 
 #include <NetworkManagerQt/ActiveConnection>
@@ -68,8 +69,10 @@ void ConnectivityMonitor::connectivityChanged(NetworkManager::Connectivity conne
                 m_notification->setComponentName(QStringLiteral("networkmanagement"));
                 m_notification->setTitle(title);
                 m_notification->setText(i18n("You need to log in to this network"));
-                connect(m_notification, &KNotification::action1Activated, this, []() {
-                    QDesktopServices::openUrl(QUrl(QStringLiteral("http://networkcheck.kde.org")));
+                connect(m_notification, &KNotification::action1Activated, this, [this]() {
+                    auto *job = new KIO::OpenUrlJob(QUrl(QStringLiteral("http://networkcheck.kde.org")));
+                    job->setStartupId(m_notification->xdgActivationToken().toUtf8());
+                    job->start();
                 });
                 m_notification->sendEvent();
             }
