@@ -8,7 +8,7 @@
 */
 
 #include "vpnc.h"
-#include "debug.h"
+#include "plasma_nm_vpnc.h"
 
 #include <QFile>
 #include <QFileInfo>
@@ -35,9 +35,7 @@ VpncUiPluginPrivate::VpncUiPluginPrivate()
     ciscoDecrypt = nullptr;
 }
 
-VpncUiPluginPrivate::~VpncUiPluginPrivate()
-{
-}
+VpncUiPluginPrivate::~VpncUiPluginPrivate() = default;
 
 QString VpncUiPluginPrivate::readStringKeyValue(const KConfigGroup &configGroup, const QString &key)
 {
@@ -54,7 +52,7 @@ void VpncUiPluginPrivate::gotCiscoDecryptOutput()
 {
     QByteArray output = ciscoDecrypt->readAll();
     if (!output.isEmpty()) {
-        QList<QByteArray> lines = output.split('\n');
+        const QList<QByteArray> lines = output.split('\n');
         if (!lines.isEmpty()) {
             decryptedPasswd = QString::fromUtf8(lines.first());
         }
@@ -71,7 +69,7 @@ void VpncUiPluginPrivate::ciscoDecryptFinished(int exitCode, QProcess::ExitStatu
 void VpncUiPluginPrivate::ciscoDecryptError(QProcess::ProcessError pError)
 {
     if (!pError) {
-        qCWarning(PLASMA_NM) << "Error in executing cisco-decrypt";
+        qCWarning(PLASMA_NM_VPNC_LOG) << "Error in executing cisco-decrypt";
         KMessageBox::error(nullptr, i18n("Error decrypting the obfuscated password"), i18n("Error"), KMessageBox::Notify);
     }
     decryptedPasswd.clear();
@@ -86,9 +84,7 @@ VpncUiPlugin::VpncUiPlugin(QObject *parent, const QVariantList &)
 {
 }
 
-VpncUiPlugin::~VpncUiPlugin()
-{
-}
+VpncUiPlugin::~VpncUiPlugin() = default;
 
 SettingWidget *VpncUiPlugin::widget(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent)
 {
@@ -102,17 +98,17 @@ SettingWidget *VpncUiPlugin::askUser(const NetworkManager::VpnSetting::Ptr &sett
 
 QString VpncUiPlugin::suggestedFileName(const NetworkManager::ConnectionSettings::Ptr &connection) const
 {
-    return connection->id() + ".pcf";
+    return connection->id() + QStringLiteral(".pcf");
 }
 
 QString VpncUiPlugin::supportedFileExtensions() const
 {
-    return "*.pcf";
+    return QStringLiteral("*.pcf");
 }
 
 NMVariantMapMap VpncUiPlugin::importConnectionSettings(const QString &fileName)
 {
-    // qCDebug(PLASMA_NM) << "Importing Cisco VPN connection from " << fileName;
+    // qCDebug(PLASMA_NM_VPNC_LOG) << "Importing Cisco VPN connection from " << fileName;
 
     VpncUiPluginPrivate *decrPlugin = nullptr;
     NMVariantMapMap result;
@@ -267,12 +263,12 @@ NMVariantMapMap VpncUiPlugin::importConnectionSettings(const QString &fileName)
             QList<NetworkManager::IpRoute> list;
             for (const QString &route : decrPlugin->readStringKeyValue(cg, "X-NM-Routes").split(' ')) {
                 NetworkManager::IpRoute ipRoute;
-                ipRoute.setIp(QHostAddress(route.split('/').first()));
-                ipRoute.setPrefixLength(route.split('/').at(1).toInt());
+                ipRoute.setIp(QHostAddress(route.split(QLatin1Char('/')).first()));
+                ipRoute.setPrefixLength(route.split(QLatin1Char('/')).at(1).toInt());
                 list << ipRoute;
             }
             QList<QList<uint>> dbusRoutes;
-            for (const NetworkManager::IpRoute &route : list) {
+            for (const NetworkManager::IpRoute &route : std::as_const(list)) {
                 QList<uint> dbusRoute;
                 dbusRoute << htonl(route.ip().toIPv4Address()) << route.prefixLength() << htonl(route.nextHop().toIPv4Address()) << route.metric();
                 dbusRoutes << dbusRoute;
@@ -282,7 +278,7 @@ NMVariantMapMap VpncUiPlugin::importConnectionSettings(const QString &fileName)
 
         // Set the '...-type' and '...-flags' value also
         NetworkManager::VpnSetting setting;
-        setting.setServiceType("org.freedesktop.NetworkManager.vpnc");
+        setting.setServiceType(QStringLiteral("org.freedesktop.NetworkManager.vpnc"));
         setting.setData(data);
         setting.setSecrets(secretData);
 
